@@ -1042,8 +1042,19 @@ func userHasTag(user *iam.User, key, val string) bool {
 }
 
 func (a *AWSActuator) createUser(logger log.FieldLogger, awsClient minteraws.Client, username string) (*iam.CreateUserOutput, error) {
-	input := &iam.CreateUserInput{
-		UserName: aws.String(username),
+	userInput := &iam.GetUserInput{}
+	currentUser, err := awsClient.GetUser(userInput)
+
+	var input *iam.CreateUserInput
+	if currentUser != nil && currentUser.User.PermissionsBoundary != nil {
+		input = &iam.CreateUserInput{
+			UserName:            aws.String(username),
+			PermissionsBoundary: currentUser.User.PermissionsBoundary.PermissionsBoundaryArn,
+		}
+	} else {
+		input = &iam.CreateUserInput{
+			UserName: aws.String(username),
+		}
 	}
 
 	uLog := logger.WithField("userName", username)
